Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Code ¶
type Code string
Code defines the code used to identify a region.
type Region ¶
type Region interface {
// Taxes provides a region's tax definition
Taxes() *tax.Region
// Currency provides the regions default currency definition.
Currency() *currency.Def
// Code provides this region's official code.
Code() Code
// Validate determines the type of GOBL document provided and attempts
// to check the contents for errors.
Validate(obj interface{}) error
}
Region represents the methods we expect to be available from a region.
Click to show internal directories.
Click to hide internal directories.