Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Message ¶
type Message struct {
// Summary of the message content
Title string `json:"title,omitempty" jsonschema:"title=Title"`
// Details of what exactly this message wants to communicate
Content string `json:"content" jsonschema:"title=Content"`
// Any additional semi-structured data that might be useful.
Meta org.Meta `json:"meta,omitempty" jsonschema:"title=Meta Data"`
}
Message represents the minimum possible contents for a GoBL document type. This is mainly meant to be used for testing purposes.
Click to show internal directories.
Click to hide internal directories.