note

package
v0.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 26, 2022 License: Apache-2.0 Imports: 3 Imported by: 2

Documentation

Index

Constants

const (
	MessageType = "note.Message"
)

Standard types provided by the note package.

Variables

This section is empty.

Functions

This section is empty.

Types

type Message

type Message struct {
	Title   string   `json:"title,omitempty" jsonschema:"title=Title,description=Summary of the message content."`
	Content string   `json:"content" jsonschema:"title=Content,description=Details of what exactly this message wants to communicate."`
	Meta    org.Meta `json:"meta,omitempty" jsonschema:"title=Meta Data,description=Any additional semi-structured data that might be useful."`
}

Message represents the minimum possible contents for a GoBL document type. This is mainly meant to be used for testing purposes.

func (Message) Type

func (Message) Type() string

Type provides the document type used for mapping.

func (*Message) Validate

func (m *Message) Validate(r region.Region) error

Validate ensures the message contains everything it should.

Jump to