Documentation
¶
Overview ¶
Package template provides a common set of tools around Go templates that help with converting data in other formats to GOBL documents.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Template ¶
type Template struct {
// contains filtered or unexported fields
}
Template contains a GOBL template document prepared for interpolating with incoming rows or objects of data.
func Must ¶
Must is a helper function that wraps a call to a function returning (*Template, error) and panics if the error is non-nil. It is intended for use in variable initializations such as
var t = template.Must(template.New("name", "..data.."))
Click to show internal directories.
Click to hide internal directories.